SuperBulletList class
Constructors
SuperBulletList ({Key ? key , required List <Widget > items , bool isOrdered = false , BulletStyle style = BulletStyle.discFill , double ? crossAxisMargin , double ? gap , Widget ? separator , Widget ? customBullet , TextStyle ? textStyle , double ? iconSize , Color ? iconColor , CrossAxisAlignment ? crossAxisAlignment })
const
Properties
bulletStylePadding
→ double
no setter
crossAxisAlignment
→ CrossAxisAlignment ?
final
crossAxisMargin
→ double ?
When set, the marker style (e.g. Roman Numeral) will be indented at the top
by this value, causing the top of the bullet list style to be misaligned
with its corresponding widget. This can be used to achieve any desired
cross-axis alignment.
final
customBullet
→ Widget ?
If non-null, this widget will replace the default bullet list style, or
override any value which was set using style .
final
gap
→ double ?
The spacing between the bullet and its corresponding widget.
final
hashCode
→ int
The hash code for this object.
no setter inherited
iconColor
→ Color ?
The icon color to use for the bullet list if its style falls within the
following options:
final
iconSize
→ double ?
The icon size to use for the bullet list if its style falls within the
following options:
final
isOrdered
→ bool
Whether the list is ordered or unordered. When set to true, the default
marker style will be set to BulletStyle.numeric unless otherwise specified.
final
items
→ List <Widget >
List of data values.
final
key
→ Key ?
Controls how one widget replaces another widget in the tree.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
separator
→ Widget ?
If non-null, this widget will be used as a separator for the individual
items of the bullet list.
final
style
→ BulletStyle
To specify the bullet type (style) to use to display list items in a
BulletList, set the BulletStyle property to one of the bullet types that
are defined by the BulletStyle enumeration.
final
textStyle
→ TextStyle ?
The textstyle to use for the bullet list if its style falls within
the following options:
final